Consulting and more — influx_si 6.0 documentation

# Consulting and more

If you need a help in design, conducting and interpretation of label experiments, you can expose your problem in a brief email to platform MetaToul-Réseaux-Métaboliques (metatoul [at] insa-toulouse [dot] fr) located in Toulouse, France. A dedicated person will take contact with your to detail what can be done to help you and to draw up a quote. For more details about the platform MetaToul, you can visit their web site (english version is available).

If you need help in topics related to mathematics, `influx_si` software itself or custom feature for `influx_si`, you can ask a project creation with Mathematics Cell in Toulouse Biotechnology Institute (sokol (at) insa-toulouse (dot) fr).

You don’t have to ask for a consulting for a simple bug submission. A bug submission can be directly made at github

If you wish to be informed about new influx_si releases and/or have discussions with influx_si users, you can subscribe to a dedicated email list [influx_si]